pub struct RegisterAction {
pub id: String,
pub default_key: KeyCode,
}Expand description
Beschreibt eine Aktion, die bei der Engine registriert werden kann.
Describes an action that can be registered with the engine.
Fields
id: StringEindeutige Aktions-ID für Scripts und das Content-Tool.
Unique action identifier used by scripts and the content tool.
default_key: KeyCodeStandard-Tastenbelegung bei der Registrierung der Aktion.
Default key binding when the action is registered.
Implementations