pub struct ActionState {
pub kind: ActionStateKind,
pub cockpit_index: Option<u8>,
pub uv: Option<Vec2>,
}Expand description
Zustand einer Aktion.
The state of an action.
Fields
kind: ActionStateKindDrück- bzw. Loslasszustand der Aktion.
Pressed/released state of the action.
cockpit_index: Option<u8>Cockpit-Index, wenn die Aktion aus einem bestimmten Cockpit stammt.
Cockpit index when the action originates from a specific cockpit.
uv: Option<Vec2>Optionale UV-Koordinaten für mausbasierte Aktionen.
Optional UV coordinates for mouse-based actions.