pub struct MessageSource {
pub coupling: Option<Coupling>,
pub module_slot_index: Option<u16>,
pub module_slot_cockpit_index: Option<u8>,
}Expand description
Quelle einer Nachricht.
Represents the source of a message.
Fields
coupling: Option<Coupling>Kupplung, über die die Nachricht von einem anderen Fahrzeug kommt, falls zutreffend.
If the message is coming from another vehicle across couplings, this will be Some.
module_slot_index: Option<u16>Modul-Slot-Index des sendenden Moduls, falls zutreffend.
If the message is coming from a module, these will be Some.
module_slot_cockpit_index: Option<u8>Cockpit-Index des sendenden Modul-Slots, falls vorhanden.
Cockpit index of the sending module slot, if applicable.
Implementations